#######################################
### TOLL-Like Receptor Pymol Script
### by Loren Dean Williams
### School of Chemistry and Biochemistry, Georgia Tech
### Based on 3wpc as described in the paper
### Ohto, U., Shibata, T., Tanji, H., Ishida, H., Krayukhina, E., Uchiyama, S.,
### Miyake, K., and Shimizu, T. (2015) Structural basis of CpG and inhibitory 
### DNA recognition by Toll-like receptor 9, Nature 520, 702-705.
####################################

reinitialize
bg_color white

#######################################
load files/3wpc.pdb, TLR9_AG_DNA_12MER
run files/python_scripts/list_hbonds.py
#######################################

####################################### create basic objects

create toll1_cartoon, chain A
create toll2_cartoon, chain B
create DNA1_cartoon, chain E
create DNA1_stick, chain E
remove resn HOH and DNA1_stick
create DNA2_cartoon, chain F
create DNA2_stick, chain F
remove resn HOH and DNA2_stick
create DNA2_surf, chain F
remove resn HOH and DNA2_surf

create temp, (toll1_cartoon or toll2_cartoon or DNA2_stick) within 8 of DNA2_stick
create protein_surf, (chain A or chain B) and temp
remove resn HOH and protein_surf
delete temp

####################################### DNA-protein interface

create interface, byres((toll1_cartoon or toll2_cartoon or DNA2_stick) within 5 of DNA2_stick)

#remove resn HOH and interface

hide everything, interface
show stick, interface

show nb_spheres, resn HOH and interface

hide everything, protein_surf
show surface, protein_surf



####################################### DNA-protein Hydrogen Bonds

list_hb interface, interface, cutoff=3.4, angle = 55, hb_list_name = HB_interface

list_hb interface, interface and resn HOH, cutoff=3.4, angle = 80, hb_list_name = HB_interface

color black, HB_interface
set dash_gap, 0.02, HB_interface
set dash_length, 0.1, HB_interface
set dash_width, 6, HB_interface
set label_size, 16, HB_interface
set label_color, yellow, HB_interface
disable HB_interface

####################################### representations

color green, toll1_cartoon
color red, ss h and toll1_cartoon
color yellow, ss s and toll1_cartoon
color green, ss l+'' and toll1_cartoon

color cyan, toll2_cartoon
color red, ss h and toll2_cartoon
color yellow, ss s and toll2_cartoon
color cyan, ss l+'' and toll2_cartoon

hide everything, toll*
show cartoon, toll1_cartoon
show cartoon, toll2_cartoon

hide everything, DNA1_cartoon
hide everything, DNA2_cartoon
show cartoon, DNA1_cartoon
show cartoon, DNA2_cartoon

set cartoon_ring_mode=3, (DNA1_cartoon or DNA2_cartoon)
set cartoon_tube_radius=0.6, (DNA1_cartoon or DNA2_cartoon)

color wheat, DNA* and name C*
color wheat, interface and name C* and chain F

color magenta, DNA* and name C* and resi 6
color magenta, interface and name C* and resi 6 and chain F


show stick, DNA1_stick
show stick, DNA2_stick
show surface, DNA2_surf

disable interface
disable DNA1_stick
disable DNA2_stick
disable protein_surf
disable DNA2_surf

set_view (\
    -0.210351095,   -0.000530647,    0.977624357,\
    -0.667528987,    0.730675459,   -0.143231601,\
    -0.714251041,   -0.682725072,   -0.154053017,\
    -0.000002533,    0.000002764, -241.013809204,\
     4.221724987,   -2.019709110,    1.102801800,\
   194.891799927,  287.133880615,  -20.000000000 )
### cut above here and paste into script ###


delete TLR9_AG_DNA_12MER

